@@ -1,26 +1,18 @@
 #ifndef _ECORE_PRIVATE_H
 #define _ECORE_PRIVATE_H
 
-#ifdef HAVE_CONFIG_H
-# include <config.h>
-#endif
-
+#include <sys/types.h>
+#include <unistd.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <sys/time.h>
-#include <sys/types.h>
-#include <unistd.h>
-#include <signal.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#include <limits.h>
-#include <dirent.h>
 
-#ifdef HAVE_SYS_MMAN_H
-# include <sys/mman.h>
+#ifdef HAVE_SIGNAL_H
+# include <signal.h>
 #endif
 
+#include <Eina.h>
+
 #ifdef EAPI
 # undef EAPI
 #endif
@@ -54,12 +46,6 @@
 # endif
 #endif
 
-#if HAVE___ATTRIBUTE__
-# define __UNUSED__ __attribute__((unused))
-#else
-# define __UNUSED__
-#endif
-
 #ifndef PATH_MAX
 # define PATH_MAX 4096
 #endif
@@ -94,6 +80,8 @@
 #define ECORE_MAGIC_EVENT           0xf77119fe
 #define ECORE_MAGIC_ANIMATOR        0xf7643ea5
 #define ECORE_MAGIC_POLLER          0xf7568127
+#define ECORE_MAGIC_PIPE            0xf7458226
+
 
 #define ECORE_MAGIC                 Ecore_Magic  __magic
 
@@ -111,7 +99,7 @@
 #undef IF_FN_DEL
 #define IF_FN_DEL(_fn, ptr) if (ptr) { _fn(ptr); ptr = NULL; }
 
-inline void ecore_print_warning(const char *function, const char *sparam);
+EAPI void ecore_print_warning(const char *function, const char *sparam);
 
 /* convenience macros for checking pointer parameters for non-NULL */
 #undef CHECK_PARAM_POINTER_RETURN
@@ -132,21 +120,6 @@ inline void ecore_print_warning(const char *function, const char *sparam);
 
 typedef unsigned int              Ecore_Magic;
 
-typedef struct _Ecore_List2       Ecore_List2;
-typedef struct _Ecore_List2_Data  Ecore_List2_Data;
-
-struct _Ecore_List2
-{
-   Ecore_List2  *next, *prev;
-   Ecore_List2  *last;
-};
-
-struct _Ecore_List2_Data
-{
-   Ecore_List2   __list_data;
-   void *data;
-};
-
 #ifndef _ECORE_H
 enum _Ecore_Fd_Handler_Flags
 {
@@ -246,12 +219,13 @@ typedef struct _Ecore_Event_Handler Ecore_Event_Handler;
 typedef struct _Ecore_Event_Filter  Ecore_Event_Filter;
 typedef struct _Ecore_Event         Ecore_Event;
 typedef struct _Ecore_Animator      Ecore_Animator;
+typedef struct _Ecore_Pipe          Ecore_Pipe;
 typedef struct _Ecore_Poller        Ecore_Poller;
 
 #ifndef _WIN32
 struct _Ecore_Exe
 {
-   Ecore_List2   __list_data;
+   EINA_INLIST;
    ECORE_MAGIC;
    pid_t        pid;
    void        *data;
@@ -287,7 +261,7 @@ struct _Ecore_Exe
 
 struct _Ecore_Timer
 {
-   Ecore_List2     __list_data;
+   EINA_INLIST;
    ECORE_MAGIC;
    double          in;
    double          at;
@@ -301,7 +275,7 @@ struct _Ecore_Timer
 
 struct _Ecore_Idler
 {
-   Ecore_List2   __list_data;
+   EINA_INLIST;
    ECORE_MAGIC;
    int          delete_me : 1;
    int        (*func) (void *data);
@@ -310,7 +284,7 @@ struct _Ecore_Idler
 
 struct _Ecore_Idle_Enterer
 {
-   Ecore_List2   __list_data;
+   EINA_INLIST;
    ECORE_MAGIC;
    int          delete_me : 1;
    int        (*func) (void *data);
@@ -319,7 +293,7 @@ struct _Ecore_Idle_Enterer
 
 struct _Ecore_Idle_Exiter
 {
-   Ecore_List2   __list_data;
+   EINA_INLIST;
    ECORE_MAGIC;
    int          delete_me : 1;
    int        (*func) (void *data);
@@ -328,7 +302,7 @@ struct _Ecore_Idle_Exiter
 
 struct _Ecore_Fd_Handler
 {
-   Ecore_List2               __list_data;
+   EINA_INLIST;
    ECORE_MAGIC;
    int                      fd;
    Ecore_Fd_Handler_Flags   flags;
@@ -346,7 +320,7 @@ struct _Ecore_Fd_Handler
 
 struct _Ecore_Event_Handler
 {
-   Ecore_List2   __list_data;
+   EINA_INLIST;
    ECORE_MAGIC;
    int          type;
    int          delete_me : 1;
@@ -356,7 +330,7 @@ struct _Ecore_Event_Handler
 
 struct _Ecore_Event_Filter
 {
-   Ecore_List2   __list_data;
+   EINA_INLIST;
    ECORE_MAGIC;
    int          delete_me : 1;
    void *     (*func_start) (void *data);
@@ -368,7 +342,7 @@ struct _Ecore_Event_Filter
 
 struct _Ecore_Event
 {
-   Ecore_List2   __list_data;
+   EINA_INLIST;
    ECORE_MAGIC;
    int          type;
    void        *event;
@@ -379,26 +353,26 @@ struct _Ecore_Event
 
 struct _Ecore_Animator
 {
-   Ecore_List2   __list_data;
+   EINA_INLIST;
    ECORE_MAGIC;
-   signed char  delete_me : 1;
-   int        (*func) (void *data);
-   void        *data;
+   unsigned char delete_me : 1;
+   int           (*func) (void *data);
+   void          *data;
 };
 
 struct _Ecore_Poller
 {
-   Ecore_List2   __list_data;
+   EINA_INLIST;
    ECORE_MAGIC;
-   int          ibit;
-   signed char  delete_me : 1;
-   int        (*func) (void *data);
-   void        *data;
+   int           ibit;
+   unsigned char delete_me : 1;
+   int           (*func) (void *data);
+   void          *data;
 };
 
 #endif
 
-EAPI void          _ecore_magic_fail(void *d, Ecore_Magic m, Ecore_Magic req_m, const char *fname);
+EAPI void          _ecore_magic_fail(const void *d, Ecore_Magic m, Ecore_Magic req_m, const char *fname);
 
 void          _ecore_timer_shutdown(void);
 void          _ecore_timer_cleanup(void);
@@ -473,5 +447,6 @@ void          _ecore_fps_debug_runtime_add(double t);
 
 
 extern int    _ecore_fps_debug;
+extern double _ecore_loop_time;
 
 #endif
