@@ -1,3 +1,14 @@
+/*
+ * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
+ */
+
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
+
+#include <stdio.h>
+#include <string.h>
+
 #include "ecore_private.h"
 #include "Ecore_DirectFB.h"
 #include "ecore_directfb_private.h"
@@ -13,7 +24,6 @@
  * - 
  * */
 
-static int _ecore_directfb_key_symbols_count = sizeof(_ecore_directfb_key_symbols)/sizeof(Ecore_DirectFB_Key_Symbols);
 static int _ecore_directfb_init_count = 0;
 
 static int _window_event_fd = 0;
@@ -43,7 +53,7 @@ static Ecore_Fd_Handler *_window_event_fd_handler_handle = NULL;
 static Ecore_Fd_Handler *_input_event_fd_handler_handle = NULL;
 
 /* this hash is to store all the possible key names for fast lookup */
-static Ecore_Hash *_ecore_directfb_key_symbols_hash = NULL;
+static Eina_Hash *_ecore_directfb_key_symbols_hash = NULL;
 
 
 static IDirectFB *_dfb = NULL;			// the main interface
@@ -85,24 +95,6 @@ _ecore_directfb_event_free_key_up(void *data __UNUSED__, void *ev)
 }
 
 
-/* helpers */
-/***********/
-int
-_ecore_directfb_hash_compare(void *key1, void *key2)
-{
-	if(*(unsigned int*)key1 == *(unsigned int*)key2)
-		return 0;
-	else
-		return 1;
-
-}
-
-unsigned int _ecore_directfb_hash_create(void *key)
-{
-	return *(unsigned int*)key % ecore_prime_table[_ecore_directfb_key_symbols_hash->size];
-}
-
-
 /* directfb window input events handler */
 /****************************************/
 
@@ -163,7 +155,7 @@ _ecore_directfb_event_handle_key_down(DFBEvent *evt)
 	{
 		case DFEC_INPUT:
 			key_symbol = evt->input.key_symbol;
-			k = ecore_hash_get(_ecore_directfb_key_symbols_hash, &key_symbol);
+			k = eina_hash_find(_ecore_directfb_key_symbols_hash, &key_symbol);
 
 			if(!k) 
 			{
@@ -179,7 +171,7 @@ _ecore_directfb_event_handle_key_down(DFBEvent *evt)
 	      
 		case DFEC_WINDOW:
 			key_symbol = evt->window.key_symbol;
-			k = ecore_hash_get(_ecore_directfb_key_symbols_hash, &key_symbol);
+			k = eina_hash_find(_ecore_directfb_key_symbols_hash, &key_symbol);
 
 			if(!k) 
 			{
@@ -211,7 +203,7 @@ _ecore_directfb_event_handle_key_up(DFBEvent *evt)
 	{
 		case DFEC_INPUT:
 			key_symbol = evt->input.key_symbol;
-			k = ecore_hash_get(_ecore_directfb_key_symbols_hash, &key_symbol);
+			k = eina_hash_find(_ecore_directfb_key_symbols_hash, &key_symbol);
 
 			
 			if(!k) 
@@ -228,7 +220,7 @@ _ecore_directfb_event_handle_key_up(DFBEvent *evt)
 	      
 		case DFEC_WINDOW:
 			key_symbol = evt->window.key_symbol;
-			k = ecore_hash_get(_ecore_directfb_key_symbols_hash, &key_symbol);
+			k = eina_hash_find(_ecore_directfb_key_symbols_hash, &key_symbol);
 
 			if(!k) 
 			{
@@ -514,7 +506,7 @@ ecore_directfb_window_new(int x, int y, int w, int h)
 }
 
 EAPI void
-ecore_directfb_window_del(Ecore_DirectFB_Window *ecore_window)
+ecore_directfb_window_free(Ecore_DirectFB_Window *ecore_window)
 {
 	DFBCHECK(ecore_window->surface->Release(ecore_window->surface));
 	DFBCHECK(ecore_window->window->Release(ecore_window->window));
@@ -662,7 +654,7 @@ ecore_directfb_window_size_get(Ecore_DirectFB_Window *ecore_window, int *w, int
 }
 
 EAPI int
-ecore_directfb_init(const char *name)
+ecore_directfb_init(const char *name __UNUSED__)
 {
 	int i = 0;
 	
@@ -698,14 +690,14 @@ ecore_directfb_init(const char *name)
 	ECORE_DIRECTFB_EVENT_WHEEL = ecore_event_type_new();;
 
 	/* create the hash table for the keynames */
-	_ecore_directfb_key_symbols_hash = ecore_hash_new(_ecore_directfb_hash_create,_ecore_directfb_hash_compare);
+	_ecore_directfb_key_symbols_hash = eina_hash_int32_new(free);
 	for(i=0; i<_ecore_directfb_key_symbols_count; i++)
 	{
 		struct keymap *k;
 		k = malloc(sizeof(struct keymap));
 		k->name = _ecore_directfb_key_symbols[i].name;
 		k->string = _ecore_directfb_key_symbols[i].string;
-		ecore_hash_set(_ecore_directfb_key_symbols_hash, &_ecore_directfb_key_symbols[i].id, k);
+		eina_hash_add(_ecore_directfb_key_symbols_hash, &_ecore_directfb_key_symbols[i].id, k);
 	}
 	/* create the hash for the windows(key = windowid, val = Ecore_DirectFB_Window struct) */
 	return _ecore_directfb_init_count;
@@ -714,8 +706,6 @@ ecore_directfb_init(const char *name)
 EAPI int
 ecore_directfb_shutdown(void)
 {
-	int i;
-
 	_ecore_directfb_init_count--;
 	if (_ecore_directfb_init_count > 0) return _ecore_directfb_init_count;
 	if (_ecore_directfb_init_count < 0)
@@ -724,15 +714,8 @@ ecore_directfb_shutdown(void)
 		return 0;
 	}
 	ecore_main_fd_handler_del(_window_event_fd_handler_handle);
-	/* free the key symbol names hash */
-	for(i=0; i<_ecore_directfb_key_symbols_count; i++)
-	{
-		struct keymap *k;
-		k = ecore_hash_get(_ecore_directfb_key_symbols_hash, &_ecore_directfb_key_symbols[i].id);
-		ecore_hash_remove(_ecore_directfb_key_symbols_hash, &_ecore_directfb_key_symbols[i].id);
-		free(k);
-	}
-	
+	eina_hash_free(_ecore_directfb_key_symbols_hash);
+
 	if(_ecore_directfb_fullscreen_window_id)
 	{
 		DFBCHECK(_input_event->Release(_input_event));	
