@@ -95,7 +95,7 @@ _ecore_evas_win32_render(Ecore_Evas *ee)
 static int
 _ecore_evas_win32_idle_enter(void *data __UNUSED__)
 {
-   Ecore_List2 *l;
+   Ecore_Evas *ee;
    double       t1 = 0.0;
    double       t2 = 0.0;
 
@@ -104,14 +104,10 @@ _ecore_evas_win32_idle_enter(void *data __UNUSED__)
      {
         t1 = ecore_time_get();
      }
-   for (l = (Ecore_List2 *)ecore_evases; l; l = l->next)
-     {
-        Ecore_Evas *ee;
-
-        ee = (Ecore_Evas *)l;
+   EINA_INLIST_FOREACH(ecore_evases, ee)
         _ecore_evas_win32_render(ee);
-     }
-/*    ecore_x_flush(); */
+
+   /*    ecore_x_flush(); */
    if (_ecore_evas_fps_debug)
      {
         t2 = ecore_time_get();
@@ -406,7 +402,7 @@ _ecore_evas_win32_free(Ecore_Evas *ee)
 
    ecore_win32_window_free(ee->prop.window);
    ecore_event_window_unregister(ee->prop.window);
-   ecore_evases = _ecore_list2_remove(ecore_evases, ee);
+   ecore_evases = (Ecore_Evas *) eina_inlist_remove(EINA_INLIST_GET(ecore_evases), EINA_INLIST_GET(ee));
    _ecore_evas_win32_shutdown();
    ecore_win32_shutdown();
 }
@@ -1098,7 +1094,7 @@ _ecore_evas_win32_new_internal(int (*_ecore_evas_engine_init)(Ecore_Evas *ee),
         return NULL;
      }
 
-   ecore_evases = _ecore_list2_prepend(ecore_evases, ee);
+   ecore_evases = (Ecore_Evas *) eina_inlist_prepend(EINA_INLIST_GET(ecore_evases), EINA_INLIST_GET(ee));
    ecore_event_window_register(ee->prop.window, ee, ee->evas, _ecore_evas_mouse_move_process);
 
    return ee;
