@@ -9,10 +9,14 @@
 #include <stdlib.h>
 #include <stdio.h>   /* for printf */
 
+#define _WIN32_WINNT 0x0500  // For WS_EX_LAYERED
+
 #define WIN32_LEAN_AND_MEAN
 #include <windows.h>
 #undef WIN32_LEAN_AND_MEAN
 
+#include <Eina.h>
+
 #include "Ecore_Win32.h"
 #include "ecore_win32_private.h"
 
@@ -46,6 +50,8 @@ ecore_win32_window_new(Ecore_Win32_Window *parent,
                        int                 width,
                        int                 height)
 {
+   EINA_ERROR_PINFO("creating window with border\n");
+
    return ecore_win32_window_internal_new(parent,
                                           x, y,
                                           width, height,
@@ -60,6 +66,8 @@ ecore_win32_window_override_new(Ecore_Win32_Window *parent,
                                 int                 width,
                                 int                 height)
 {
+   EINA_ERROR_PINFO("creating window without border\n");
+
    return ecore_win32_window_internal_new(parent,
                                           x, y,
                                           width, height,
@@ -67,13 +75,19 @@ ecore_win32_window_override_new(Ecore_Win32_Window *parent,
 }
 
 void
-ecore_win32_window_del(Ecore_Win32_Window *window)
+ecore_win32_window_free(Ecore_Win32_Window *window)
 {
+   struct _Ecore_Win32_Window *wnd = window;
+
    if (!window) return;
 
+   EINA_ERROR_PINFO("destroying window\n");
+
+   if (wnd->shape.mask != NULL)
+      free(wnd->shape.mask);
+
    DestroyWindow(((struct _Ecore_Win32_Window *)window)->window);
    free(window);
-   printf ("ecore_win32_window_del\n");
 }
 
 void *
@@ -126,15 +140,22 @@ ecore_win32_window_move(Ecore_Win32_Window *window,
 
    if (!window) return;
 
-   printf ("ecore_win32_window_move %p : %d %d\n", window, x, y);
+   EINA_ERROR_PINFO("moving window (%dx%d)\n", x, y);
+
    w = ((struct _Ecore_Win32_Window *)window)->window;
    if (!GetWindowRect(w, &rect))
-     return;
+     {
+        EINA_ERROR_PERR("GetWindowRect() failed\n");
+        return;
+     }
 
-   MoveWindow(w, x, y,
-              rect.right - rect.left,
-              rect.bottom - rect.top,
-              TRUE);
+   if (!MoveWindow(w, x, y,
+                   rect.right - rect.left,
+                   rect.bottom - rect.top,
+                   TRUE))
+     {
+        EINA_ERROR_PERR("MoveWindow() failed\n");
+     }
 }
 
 void
@@ -150,17 +171,14 @@ ecore_win32_window_resize(Ecore_Win32_Window *window,
 
    if (!window) return;
 
-   w = (struct _Ecore_Win32_Window *)window;
-   if (!GetWindowRect(w->window, &rect)) return;
+   EINA_ERROR_PINFO("resizing window (%dx%d)\n", width, height);
 
-   printf ("ecore_win32_window_resize 0 : %p (%d %d) (%d %d) (%d %d)\n",
-           w,
-           w->min_width,
-           w->min_height,
-           w->max_width,
-           w->max_height,
-           width,
-           height);
+   w = (struct _Ecore_Win32_Window *)window;
+   if (!GetWindowRect(w->window, &rect))
+     {
+        EINA_ERROR_PERR("GetWindowRect() failed\n");
+        return;
+     }
 
    x = rect.left;
    y = rect.top;
@@ -175,18 +193,24 @@ ecore_win32_window_resize(Ecore_Win32_Window *window,
 /*    printf ("ecore_win32_window_resize 3 : %d %d\n", w->max_height, height); */
    rect.right = width;
    rect.bottom = height;
-   style = GetWindowLong(w->window, GWL_STYLE);
+   if (!(style = GetWindowLong(w->window, GWL_STYLE)))
+     {
+        EINA_ERROR_PERR("GetWindowLong() failed\n");
+        return;
+     }
    if (!AdjustWindowRect(&rect, style, FALSE))
-     return;
+     {
+        EINA_ERROR_PERR("AdjustWindowRect() failed\n");
+        return;
+     }
 
    if (!MoveWindow(w->window, x, y,
                    rect.right - rect.left,
                    rect.bottom - rect.top,
-                   FALSE))
+                   TRUE))
      {
-       printf (" MEEERDE !!!\n");
+        EINA_ERROR_PERR("MoveWindow() failed\n");
      }
-   printf ("ecore_win32_window_resize 4 : %d %d\n", width, height);
 }
 
 void
@@ -202,7 +226,8 @@ ecore_win32_window_move_resize(Ecore_Win32_Window *window,
 
    if (!window) return;
 
-   printf ("ecore_win32_window_move_resize 0 : %p  %d %d\n", window, width, height);
+   EINA_ERROR_PINFO("moving and resizing window (%dx%d %dx%d)\n", x, y, width, height);
+
    w = ((struct _Ecore_Win32_Window *)window);
    rect.left = 0;
    rect.top = 0;
@@ -210,17 +235,26 @@ ecore_win32_window_move_resize(Ecore_Win32_Window *window,
    if ((unsigned int)width > w->max_width) width = w->max_width;
    if ((unsigned int)height < w->min_height) height = w->min_height;
    if ((unsigned int)height > w->max_height) height = w->max_height;
-   printf ("ecore_win32_window_move_resize 1 : %d %d\n", width, height);
    rect.right = width;
    rect.bottom = height;
-   style = GetWindowLong(w->window, GWL_STYLE);
-   if (!AdjustWindowRect(&rect, WS_OVERLAPPEDWINDOW | WS_SIZEBOX, FALSE))
-     return;
+   if (!(style = GetWindowLong(w->window, GWL_STYLE)))
+     {
+        EINA_ERROR_PERR("GetWindowLong() failed\n");
+        return;
+     }
+   if (!AdjustWindowRect(&rect, style, FALSE))
+     {
+        EINA_ERROR_PERR("AdjustWindowRect() failed\n");
+        return;
+     }
 
-   MoveWindow(w->window, x, y,
-              rect.right - rect.left,
-              rect.bottom - rect.top,
-              TRUE);
+   if (!MoveWindow(w->window, x, y,
+                   rect.right - rect.left,
+                   rect.bottom - rect.top,
+                   TRUE))
+     {
+        EINA_ERROR_PERR("MoveWindow() failed\n");
+     }
 }
 
 void
@@ -234,7 +268,8 @@ ecore_win32_window_geometry_get(Ecore_Win32_Window *window,
    int  w;
    int  h;
 
-   printf ("ecore_win32_window_geometry_get %p\n", window);
+   EINA_ERROR_PINFO("getting window geometry\n");
+
    if (!window)
      {
         if (x) *x = 0;
@@ -248,6 +283,8 @@ ecore_win32_window_geometry_get(Ecore_Win32_Window *window,
    if (!GetClientRect(((struct _Ecore_Win32_Window *)window)->window,
                       &rect))
      {
+        EINA_ERROR_PERR("GetClientRect() failed\n");
+
         if (x) *x = 0;
         if (y) *y = 0;
         if (width) *width = 0;
@@ -262,6 +299,8 @@ ecore_win32_window_geometry_get(Ecore_Win32_Window *window,
    if (!GetWindowRect(((struct _Ecore_Win32_Window *)window)->window,
                       &rect))
      {
+        EINA_ERROR_PERR("GetWindowRect() failed\n");
+
         if (x) *x = 0;
         if (y) *y = 0;
         if (width) *width = 0;
@@ -283,7 +322,8 @@ ecore_win32_window_size_get(Ecore_Win32_Window *window,
 {
    RECT rect;
 
-   printf ("ecore_win32_window_size_get %p\n", window);
+   EINA_ERROR_PINFO("getting window size\n");
+
    if (!window)
      {
         if (width) *width = GetSystemMetrics(SM_CXSCREEN);
@@ -295,6 +335,8 @@ ecore_win32_window_size_get(Ecore_Win32_Window *window,
    if (!GetClientRect(((struct _Ecore_Win32_Window *)window)->window,
                       &rect))
      {
+        EINA_ERROR_PERR("GetClientRect() failed\n");
+
         if (width) *width = 0;
         if (height) *height = 0;
      }
@@ -423,16 +465,155 @@ ecore_win32_window_size_step_get(Ecore_Win32_Window *window,
    if (step_height) *step_height = w->step_height;
 }
 
-/* TODO: ecore_win32_window_shaped_set */
+void
+ecore_win32_window_shape_set(Ecore_Win32_Window *window,
+                             unsigned short      width,
+                             unsigned short      height,
+                             unsigned char      *mask)
+{
+   struct _Ecore_Win32_Window *wnd;
+   HRGN                        rgn;
+   int                         x;
+   int                         y;
+   OSVERSIONINFO               version_info;
+
+   if (window == NULL)
+      return;
+
+   wnd = (struct _Ecore_Win32_Window *)window;
+
+   if (mask == NULL)
+     {
+        wnd->shape.enabled = 0;
+        if (wnd->shape.layered != 0)
+          {
+             wnd->shape.layered = 0;
+#if defined(WS_EX_LAYERED)
+             SetLastError(0);
+             if (!SetWindowLongPtr(wnd->window, GWL_EXSTYLE,
+                                   GetWindowLong(wnd->window, GWL_EXSTYLE) & (~WS_EX_LAYERED)) &&
+                 (GetLastError() != 0))
+               {
+                  EINA_ERROR_PERR("SetWindowLongPtr() failed\n");
+                  return;
+               }
+             if (!RedrawWindow(wnd->window, NULL, NULL,
+                               RDW_ERASE | RDW_INVALIDATE | RDW_FRAME | RDW_ALLCHILDREN))
+               {
+                  EINA_ERROR_PERR("RedrawWindow() failed\n");
+                  return;
+               }
+#endif
+          }
+        else
+          if (!SetWindowRgn(wnd->window, NULL, TRUE))
+            {
+               EINA_ERROR_PERR("SetWindowRgn() failed\n");
+            }
+        return;
+     }
+
+   if (width == 0 || height == 0)
+     return;
+
+   wnd->shape.enabled = 1;
+
+   if (width != wnd->shape.width || height != wnd->shape.height)
+     {
+       wnd->shape.width = width;
+       wnd->shape.height = height;
+       if (wnd->shape.mask != NULL)
+         {
+           free(wnd->shape.mask);
+           wnd->shape.mask = NULL;
+         }
+       wnd->shape.mask = malloc(width * height);
+     }
+   memcpy(wnd->shape.mask, mask, width * height);
+
+   wnd->shape.layered = 0;
+
+#if defined(WS_EX_LAYERED)
+   version_info.dwOSVersionInfoSize = sizeof(version_info);
+   if (GetVersionEx(&version_info) == TRUE && version_info.dwMajorVersion == 5)
+     {
+       SetLastError(0);
+       if (!SetWindowLongPtr(wnd->window, GWL_EXSTYLE,
+                             GetWindowLong(wnd->window, GWL_EXSTYLE) | WS_EX_LAYERED) &&
+           (GetLastError() != 0))
+            {
+               EINA_ERROR_PERR("SetWindowLongPtr() failed\n");
+               return;
+            }
+       wnd->shape.layered = 1;
+       return;
+     }
+#endif
+
+   if (!(rgn = CreateRectRgn(0, 0, 0, 0)))
+     {
+        EINA_ERROR_PERR("CreateRectRgn() failed\n");
+        return;
+     }
+   for (y = 0; y < height; y++)
+     {
+        HRGN rgnLine;
+
+        if (!(rgnLine = CreateRectRgn(0, 0, 0, 0)))
+          {
+             EINA_ERROR_PERR("CreateRectRgn() failed\n");
+             return;
+          }
+        for (x = 0; x < width; x++)
+          {
+             if (mask[y * width + x] > 0)
+               {
+                  HRGN rgnDot;
+
+                  if (!(rgnDot = CreateRectRgn(x, y, x + 1, y + 1)))
+                    {
+                       EINA_ERROR_PERR("CreateRectRgn() failed\n");
+                       return;
+                    }
+                  if (CombineRgn(rgnLine, rgnLine, rgnDot, RGN_OR) == ERROR)
+                    {
+                       EINA_ERROR_PERR("CombineRgn() has not created a new region\n");
+                    }
+                  if (!DeleteObject(rgnDot))
+                    {
+                       EINA_ERROR_PERR("DeleteObject() failed\n");
+                       return;
+                    }
+               }
+          }
+        if (CombineRgn(rgn, rgn, rgnLine, RGN_OR) == ERROR)
+          {
+             EINA_ERROR_PERR("CombineRgn() has not created a new region\n");
+          }
+        if (!DeleteObject(rgnLine))
+          {
+             EINA_ERROR_PERR("DeleteObject() failed\n");
+             return;
+          }
+     }
+   if (!SetWindowRgn(wnd->window, rgn, TRUE))
+     {
+        EINA_ERROR_PERR("SetWindowRgn() failed\n");
+     }
+}
 
 void
 ecore_win32_window_show(Ecore_Win32_Window *window)
 {
    if (!window) return;
 
-   printf (" ** ecore_win32_window_show  %p\n", window);
+   EINA_ERROR_PINFO("showing window\n");
+
    ShowWindow(((struct _Ecore_Win32_Window *)window)->window, SW_SHOWNORMAL);
-   UpdateWindow(((struct _Ecore_Win32_Window *)window)->window);
+   if (!UpdateWindow(((struct _Ecore_Win32_Window *)window)->window))
+     {
+        EINA_ERROR_PERR("UpdateWindow() failed\n");
+     }
 }
 
 /* FIXME: seems to block the taskbar */
@@ -441,7 +622,8 @@ ecore_win32_window_hide(Ecore_Win32_Window *window)
 {
    if (!window) return;
 
-   printf (" ** ecore_win32_window_hide  %p\n", window);
+   EINA_ERROR_PINFO("hiding window\n");
+
    ShowWindow(((struct _Ecore_Win32_Window *)window)->window, SW_HIDE);
 }
 
@@ -450,10 +632,14 @@ ecore_win32_window_raise(Ecore_Win32_Window *window)
 {
    if (!window) return;
 
-   printf (" ** ecore_win32_window_raise  %p\n", window);
-   SetWindowPos(((struct _Ecore_Win32_Window *)window)->window,
-                HWND_TOP, 0, 0, 0, 0,
-                SWP_NOACTIVATE | SWP_NOMOVE | SWP_NOSIZE);
+   EINA_ERROR_PINFO("raising window\n");
+
+   if (!SetWindowPos(((struct _Ecore_Win32_Window *)window)->window,
+                     HWND_TOP, 0, 0, 0, 0,
+                     SWP_NOACTIVATE | SWP_NOMOVE | SWP_NOSIZE))
+     {
+        EINA_ERROR_PERR("SetWindowPos() failed\n");
+     }
 }
 
 void
@@ -461,10 +647,14 @@ ecore_win32_window_lower(Ecore_Win32_Window *window)
 {
    if (!window) return;
 
-   printf (" ** ecore_win32_window_lower  %p\n", window);
-   SetWindowPos(((struct _Ecore_Win32_Window *)window)->window,
-                HWND_BOTTOM, 0, 0, 0, 0,
-                SWP_NOACTIVATE | SWP_NOMOVE | SWP_NOSIZE);
+   EINA_ERROR_PINFO("lowering window\n");
+
+   if (!SetWindowPos(((struct _Ecore_Win32_Window *)window)->window,
+                     HWND_BOTTOM, 0, 0, 0, 0,
+                     SWP_NOACTIVATE | SWP_NOMOVE | SWP_NOSIZE))
+     {
+        EINA_ERROR_PERR("SetWindowPos() failed\n");
+     }
 }
 
 void
@@ -475,7 +665,12 @@ ecore_win32_window_title_set(Ecore_Win32_Window *window,
 
    if (!title || !title[0]) return;
 
-   SetWindowText(((struct _Ecore_Win32_Window *)window)->window, title);
+   EINA_ERROR_PINFO("setting window title\n");
+
+   if (!SetWindowText(((struct _Ecore_Win32_Window *)window)->window, title))
+     {
+        EINA_ERROR_PERR("SetWindowText() failed\n");
+     }
 }
 
 void
@@ -483,7 +678,12 @@ ecore_win32_window_focus_set(Ecore_Win32_Window *window)
 {
    if (!window) return;
 
-   SetFocus(((struct _Ecore_Win32_Window *)window)->window);
+   EINA_ERROR_PINFO("focusing window\n");
+
+   if (!SetFocus(((struct _Ecore_Win32_Window *)window)->window))
+     {
+        EINA_ERROR_PERR("SetFocus() failed\n");
+     }
 }
 
 void
@@ -499,16 +699,9 @@ ecore_win32_window_iconified_set(Ecore_Win32_Window *window,
        ((!ew->iconified) && (!on)))
      return;
 
-   if (on)
-     {
-        ShowWindow(ew->window,
-                   SW_MINIMIZE);
-     }
-   else
-     {
-        ShowWindow(ew->window,
-                   SW_RESTORE);
-     }
+   EINA_ERROR_PINFO("iconifying window: %s\n", on ? "yes" : "no");
+
+   ShowWindow(ew->window, on ? SW_MINIMIZE : SW_RESTORE);
    ew->iconified = on;
 }
 
@@ -523,31 +716,58 @@ ecore_win32_window_borderless_set(Ecore_Win32_Window *window,
 
    if (!window) return;
 
-   printf (" ** ecore_win32_window_borderless_set  %p  %d\n", window, on);
    ew = (struct _Ecore_Win32_Window *)window;
    if (((ew->borderless) && (on)) ||
        ((!ew->borderless) && (!on)))
      return;
 
+   EINA_ERROR_PINFO("setting window without border: %s\n", on ? "yes" : "no");
+
    w = ew->window;
 
    style = GetWindowLong(w, GWL_STYLE);
    if (on)
      {
-        if (!GetClientRect(w, &rect)) return;
-        SetWindowLong(w, GWL_STYLE, style & ~WS_CAPTION);
+        if (!GetClientRect(w, &rect))
+          {
+             EINA_ERROR_PERR("GetClientRect() failed\n");
+             return;
+          }
+        SetLastError(0);
+        if (!SetWindowLongPtr(w, GWL_STYLE, style & ~(WS_CAPTION | WS_THICKFRAME)) && (GetLastError() != 0))
+          {
+             EINA_ERROR_PERR("SetWindowLongPtr() failed\n");
+             return;
+          }
      }
    else
      {
-        if (!GetWindowRect(w, &rect)) return;
-        style |= WS_CAPTION;
-        AdjustWindowRect (&rect, style, FALSE);
-        SetWindowLong(w, GWL_STYLE, style);
+        if (!GetWindowRect(w, &rect))
+          {
+             EINA_ERROR_PERR("GetWindowRect() failed\n");
+             return;
+          }
+        style |= WS_CAPTION | WS_THICKFRAME;
+        if (!AdjustWindowRect (&rect, style, FALSE))
+          {
+             EINA_ERROR_PERR("AdjustWindowRect() failed\n");
+             return;
+          }
+        SetLastError(0);
+        if (!SetWindowLongPtr(w, GWL_STYLE, style) && (GetLastError() != 0))
+          {
+             EINA_ERROR_PERR("SetWindowLongPtr() failed\n");
+             return;
+          }
+     }
+   if (!SetWindowPos(w, HWND_TOPMOST,
+                     rect.left, rect.top,
+                     rect.right - rect.left, rect.bottom - rect.top,
+                     SWP_NOMOVE | SWP_FRAMECHANGED))
+     {
+        EINA_ERROR_PERR("SetWindowPos() failed\n");
+        return;
      }
-   SetWindowPos(w, HWND_TOPMOST,
-                rect.left, rect.top,
-                rect.right - rect.left, rect.bottom - rect.top,
-                SWP_NOMOVE | SWP_FRAMECHANGED);
    ew->borderless = on;
 }
 
@@ -557,8 +777,6 @@ ecore_win32_window_fullscreen_set(Ecore_Win32_Window *window,
 {
    struct _Ecore_Win32_Window *ew;
    HWND                        w;
-   int                         width;
-   int                         height;
 
    if (!window) return;
 
@@ -567,31 +785,71 @@ ecore_win32_window_fullscreen_set(Ecore_Win32_Window *window,
        ((!ew->fullscreen) && (!on)))
      return;
 
-   ew->fullscreen = on;
+   EINA_ERROR_PINFO("setting fullscreen: %s\n", on ? "yes" : "no");
+
+   ew->fullscreen = !!on;
    w = ew->window;
 
    if (on)
      {
-        if (!GetWindowRect(w, &ew->rect)) return;
-        ew->style = GetWindowLong(w, GWL_STYLE);
-        width = GetSystemMetrics (SM_CXSCREEN);
-        height = GetSystemMetrics (SM_CYSCREEN);
-        if (!SetWindowLong(w, GWL_STYLE,
-                           (ew->style & ~WS_OVERLAPPEDWINDOW) | WS_POPUP))
-          return;
-        SetWindowPos(w, HWND_TOP, 0, 0, width, height,
-                     SWP_NOCOPYBITS | SWP_SHOWWINDOW);
+        DWORD style;
+
+        if (!GetWindowRect(w, &ew->rect))
+          {
+             EINA_ERROR_PERR("GetWindowRect() failed\n");
+             return;
+          }
+        if (!(ew->style = GetWindowLong(w, GWL_STYLE)))
+          {
+             EINA_ERROR_PERR("GetWindowLong() failed\n");
+             return;
+          }
+        style = ew->style & ~WS_OVERLAPPEDWINDOW & ~WS_SIZEBOX;
+        style |= WS_VISIBLE | WS_POPUP;
+        SetLastError(0);
+        if (!SetWindowLongPtr(w, GWL_STYLE, style) && (GetLastError() != 0))
+          {
+             EINA_ERROR_PERR("SetWindowLongPtr() failed\n");
+             return;
+          }
+        SetLastError(0);
+        if (!SetWindowLongPtr(w, GWL_EXSTYLE, WS_EX_TOPMOST) && (GetLastError() != 0))
+          {
+             EINA_ERROR_PERR("SetWindowLongPtr() failed\n");
+             return;
+          }
+        if (!SetWindowPos(w, HWND_TOPMOST, 0, 0,
+                          GetSystemMetrics (SM_CXSCREEN), GetSystemMetrics (SM_CYSCREEN),
+                          SWP_NOCOPYBITS | SWP_SHOWWINDOW))
+          {
+             EINA_ERROR_PERR("SetWindowPos() failed\n");
+             return;
+          }
      }
    else
      {
-        if (!SetWindowLong(w, GWL_STYLE, ew->style))
-          return;
-        SetWindowPos(w, HWND_NOTOPMOST,
-                     ew->rect.left,
-                     ew->rect.top,
-                     ew->rect.right - ew->rect.left,
-                     ew->rect.bottom - ew->rect.top,
-                     SWP_NOCOPYBITS | SWP_SHOWWINDOW);
+        SetLastError(0);
+        if (!SetWindowLongPtr(w, GWL_STYLE, ew->style) && (GetLastError() != 0))
+          {
+             EINA_ERROR_PERR("SetWindowLongPtr() failed\n");
+             return;
+          }
+        SetLastError(0);
+        if (!SetWindowLongPtr(w, GWL_EXSTYLE, 0) && (GetLastError() != 0))
+          {
+             EINA_ERROR_PERR("SetWindowLongPtr() failed\n");
+             return;
+          }
+        if (!SetWindowPos(w, HWND_NOTOPMOST,
+                          ew->rect.left,
+                          ew->rect.top,
+                          ew->rect.right - ew->rect.left,
+                          ew->rect.bottom - ew->rect.top,
+                          SWP_NOCOPYBITS | SWP_SHOWWINDOW))
+          {
+             EINA_ERROR_PERR("SetWindowPos() failed\n");
+             return;
+          }
      }
 }
 
@@ -599,8 +857,13 @@ void
 ecore_win32_window_cursor_set(Ecore_Win32_Window *window,
                               Ecore_Win32_Cursor *cursor)
 {
-   SetClassLong(((struct _Ecore_Win32_Window *)window)->window,
-                GCL_HCURSOR, (LONG)cursor);
+   EINA_ERROR_PINFO("setting cursor\n");
+
+   if (!SetClassLong(((struct _Ecore_Win32_Window *)window)->window,
+                     GCL_HCURSOR, (LONG)cursor))
+     {
+        EINA_ERROR_PERR("SetClassLong() failed\n");
+     }
 }
 
 void
@@ -610,9 +873,11 @@ ecore_win32_window_state_set(Ecore_Win32_Window       *window,
 {
    unsigned int i;
 
-   if (!num)
+   if (!window || !state || !num)
      return;
 
+   EINA_ERROR_PINFO("setting cursor state\n");
+
    for (i = 0; i < num; i++)
      {
         switch (state[i])
@@ -666,107 +931,136 @@ ecore_win32_window_state_request_send(Ecore_Win32_Window      *window,
                                       Ecore_Win32_Window_State state,
                                       unsigned int             set)
 {
-  if (!window)
-    return;
+   if (!window)
+     return;
+
+   EINA_ERROR_PINFO("sending cursor state\n");
 
    switch (state)
      {
-     case ECORE_WIN32_WINDOW_STATE_ICONIFIED:
-       if (((struct _Ecore_Win32_Window *)window)->state.iconified)
-         ecore_win32_window_iconified_set(window, set);
-       break;
-     case ECORE_WIN32_WINDOW_STATE_MODAL:
-       ((struct _Ecore_Win32_Window *)window)->state.modal = 1;
-       break;
-     case ECORE_WIN32_WINDOW_STATE_STICKY:
-       ((struct _Ecore_Win32_Window *)window)->state.sticky = 1;
-       break;
-     case ECORE_WIN32_WINDOW_STATE_MAXIMIZED_VERT:
-       if (((struct _Ecore_Win32_Window *)window)->state.maximized_vert)
-         {
-            RECT rect;
-            int  y;
-            int  height;
+      case ECORE_WIN32_WINDOW_STATE_ICONIFIED:
+         if (((struct _Ecore_Win32_Window *)window)->state.iconified)
+           ecore_win32_window_iconified_set(window, set);
+         break;
+      case ECORE_WIN32_WINDOW_STATE_MODAL:
+         ((struct _Ecore_Win32_Window *)window)->state.modal = 1;
+         break;
+      case ECORE_WIN32_WINDOW_STATE_STICKY:
+         ((struct _Ecore_Win32_Window *)window)->state.sticky = 1;
+         break;
+      case ECORE_WIN32_WINDOW_STATE_MAXIMIZED_VERT:
+         if (((struct _Ecore_Win32_Window *)window)->state.maximized_vert)
+           {
+              RECT rect;
+              int  y;
+              int  height;
 
-            if (!SystemParametersInfo(SPI_GETWORKAREA, 0,
-                                      &rect, 0))
-              break;
-            y = rect.top;
-            height = rect.bottom - rect.top;
+              if (!SystemParametersInfo(SPI_GETWORKAREA, 0,
+                                        &rect, 0))
+                {
+                   EINA_ERROR_PERR("SystemParametersInfo() failed\n");
+                   break;
+                }
+              y = rect.top;
+              height = rect.bottom - rect.top;
 
-            if (!GetClientRect(((struct _Ecore_Win32_Window *)window)->window,
-                               &rect))
-              break;
+              if (!GetClientRect(((struct _Ecore_Win32_Window *)window)->window,
+                                 &rect))
+                {
+                   EINA_ERROR_PERR("GetClientRect() failed\n");
+                   break;
+                }
 
-            MoveWindow(window, rect.left, y,
-                       rect.right - rect.left,
-                       height,
-                       TRUE);
-         }
-       break;
-     case ECORE_WIN32_WINDOW_STATE_MAXIMIZED_HORZ:
-       if (((struct _Ecore_Win32_Window *)window)->state.maximized_horz)
-         {
-            RECT rect;
+              if (!MoveWindow(window, rect.left, y,
+                              rect.right - rect.left,
+                              height,
+                              TRUE))
+                {
+                   EINA_ERROR_PERR("MoveWindow() failed\n");
+                }
+           }
+         break;
+      case ECORE_WIN32_WINDOW_STATE_MAXIMIZED_HORZ:
+         if (((struct _Ecore_Win32_Window *)window)->state.maximized_horz)
+           {
+              RECT rect;
 
-            if (!GetClientRect(((struct _Ecore_Win32_Window *)window)->window,
-                               &rect))
-              break;
+              if (!GetClientRect(((struct _Ecore_Win32_Window *)window)->window,
+                                 &rect))
+                {
+                   EINA_ERROR_PERR("GetClientRect() failed\n");
+                   break;
+                }
 
-            MoveWindow(window, 0, rect.top,
-                       GetSystemMetrics(SM_CXSCREEN),
-                       rect.bottom - rect.top,
-                       TRUE);
-         }
-       break;
-     case ECORE_WIN32_WINDOW_STATE_MAXIMIZED:
-       if (((struct _Ecore_Win32_Window *)window)->state.maximized_vert &&
-           ((struct _Ecore_Win32_Window *)window)->state.maximized_horz)
-         {
-            RECT rect;
+              if (!MoveWindow(window, 0, rect.top,
+                              GetSystemMetrics(SM_CXSCREEN),
+                              rect.bottom - rect.top,
+                              TRUE))
+                {
+                   EINA_ERROR_PERR("MoveWindow() failed\n");
+                }
+           }
+         break;
+      case ECORE_WIN32_WINDOW_STATE_MAXIMIZED:
+         if (((struct _Ecore_Win32_Window *)window)->state.maximized_vert &&
+             ((struct _Ecore_Win32_Window *)window)->state.maximized_horz)
+           {
+              RECT rect;
 
-            if (!SystemParametersInfo(SPI_GETWORKAREA, 0,
-                                      &rect, 0))
-              break;
+              if (!SystemParametersInfo(SPI_GETWORKAREA, 0,
+                                        &rect, 0))
+                {
+                   EINA_ERROR_PERR("SystemParametersInfo() failed\n");
+                   break;
+                }
 
-            MoveWindow(window, 0, 0,
-                       GetSystemMetrics(SM_CXSCREEN),
-                       rect.bottom - rect.top,
-                       TRUE);
-         }
-       break;
-     case ECORE_WIN32_WINDOW_STATE_SHADED:
-       ((struct _Ecore_Win32_Window *)window)->state.shaded = 1;
-       break;
-     case ECORE_WIN32_WINDOW_STATE_HIDDEN:
-       ((struct _Ecore_Win32_Window *)window)->state.hidden = 1;
-       break;
-     case ECORE_WIN32_WINDOW_STATE_FULLSCREEN:
-       if (((struct _Ecore_Win32_Window *)window)->state.fullscreen)
-         ecore_win32_window_fullscreen_set(window, set);
-       break;
-     case ECORE_WIN32_WINDOW_STATE_ABOVE:
-       if (((struct _Ecore_Win32_Window *)window)->state.above)
-         SetWindowPos(((struct _Ecore_Win32_Window *)window)->window,
-                      HWND_TOP,
-                      0, 0,
-                      0, 0,
-                      SWP_NOMOVE | SWP_NOSIZE | SWP_SHOWWINDOW);
-       break;
-     case ECORE_WIN32_WINDOW_STATE_BELOW:
-       if (((struct _Ecore_Win32_Window *)window)->state.below)
-         SetWindowPos(((struct _Ecore_Win32_Window *)window)->window,
-                      HWND_BOTTOM,
-                      0, 0,
-                      0, 0,
-                      SWP_NOMOVE | SWP_NOSIZE | SWP_SHOWWINDOW);
-       break;
-     case ECORE_WIN32_WINDOW_STATE_DEMANDS_ATTENTION:
-       ((struct _Ecore_Win32_Window *)window)->state.demands_attention = 1;
-       break;
-     case ECORE_WIN32_WINDOW_STATE_UNKNOWN:
-       /* nothing to be done */
-       break;
+              if (!MoveWindow(window, 0, 0,
+                              GetSystemMetrics(SM_CXSCREEN),
+                              rect.bottom - rect.top,
+                              TRUE))
+                {
+                   EINA_ERROR_PERR("MoveWindow() failed\n");
+                }
+           }
+         break;
+      case ECORE_WIN32_WINDOW_STATE_SHADED:
+         ((struct _Ecore_Win32_Window *)window)->state.shaded = 1;
+         break;
+      case ECORE_WIN32_WINDOW_STATE_HIDDEN:
+         ((struct _Ecore_Win32_Window *)window)->state.hidden = 1;
+         break;
+      case ECORE_WIN32_WINDOW_STATE_FULLSCREEN:
+         if (((struct _Ecore_Win32_Window *)window)->state.fullscreen)
+           ecore_win32_window_fullscreen_set(window, set);
+         break;
+      case ECORE_WIN32_WINDOW_STATE_ABOVE:
+         if (((struct _Ecore_Win32_Window *)window)->state.above)
+           if (!SetWindowPos(((struct _Ecore_Win32_Window *)window)->window,
+                             HWND_TOP,
+                             0, 0,
+                             0, 0,
+                             SWP_NOMOVE | SWP_NOSIZE | SWP_SHOWWINDOW))
+             {
+                EINA_ERROR_PERR("SetWindowPos() failed\n");
+             }
+         break;
+      case ECORE_WIN32_WINDOW_STATE_BELOW:
+         if (((struct _Ecore_Win32_Window *)window)->state.below)
+           if (!SetWindowPos(((struct _Ecore_Win32_Window *)window)->window,
+                             HWND_BOTTOM,
+                             0, 0,
+                             0, 0,
+                             SWP_NOMOVE | SWP_NOSIZE | SWP_SHOWWINDOW))
+             {
+                EINA_ERROR_PERR("SetWindowPos() failed\n");
+             }
+         break;
+      case ECORE_WIN32_WINDOW_STATE_DEMANDS_ATTENTION:
+         ((struct _Ecore_Win32_Window *)window)->state.demands_attention = 1;
+         break;
+      case ECORE_WIN32_WINDOW_STATE_UNKNOWN:
+         /* nothing to be done */
+         break;
      }
 }
 
@@ -774,6 +1068,11 @@ void
 ecore_win32_window_type_set(Ecore_Win32_Window      *window,
                             Ecore_Win32_Window_Type  type)
 {
+   if (!window)
+     return;
+
+   EINA_ERROR_PINFO("setting window type\n");
+
    switch (type)
      {
      case ECORE_WIN32_WINDOW_TYPE_DESKTOP:
@@ -824,22 +1123,21 @@ ecore_win32_window_internal_new(Ecore_Win32_Window *parent,
 
    w = (struct _Ecore_Win32_Window *)calloc(1, sizeof(struct _Ecore_Win32_Window));
    if (!w)
-     return NULL;
+     {
+        EINA_ERROR_PERR("malloc() failed\n");
+        return NULL;
+     }
 
-   printf (" *** ecore_win32_window_new : %p  %d %d %d\n",
-           w,
-           width, height, GetSystemMetrics(SM_CXMIN));
    rect.left = 0;
    rect.top = 0;
    rect.right = width;
    rect.bottom = height;
    if (!AdjustWindowRect(&rect, style, FALSE))
      {
+        EINA_ERROR_PERR("AdjustWindowRect() failed\n");
         free(w);
         return NULL;
      }
-   printf (" * ecore : new debut : %ld %d %d\n",
-           rect.right - rect.left, GetSystemMetrics(SM_CXMIN), GetSystemMetrics(SM_CYMIN));
 
    minimal_width = GetSystemMetrics(SM_CXMIN);
    minimal_height = GetSystemMetrics(SM_CYMIN);
@@ -856,22 +1154,25 @@ ecore_win32_window_internal_new(Ecore_Win32_Window *parent,
        rect.right = rect.left + minimal_width;
      }
 
-   w->window = CreateWindow(ECORE_WIN32_WINDOW_CLASS, "",
-                            style,
-                            x, y,
-                            rect.right - rect.left,
-                            rect.bottom - rect.top,
-                            parent ? ((struct _Ecore_Win32_Window *)parent)->window : NULL,
-                            NULL, _ecore_win32_instance, NULL);
+   w->window = CreateWindowEx(0,
+                              ECORE_WIN32_WINDOW_CLASS, "",
+                              style,
+                              x, y,
+                              rect.right - rect.left,
+                              rect.bottom - rect.top,
+                              parent ? ((struct _Ecore_Win32_Window *)parent)->window : NULL,
+                              NULL, _ecore_win32_instance, NULL);
    if (!w->window)
      {
+        EINA_ERROR_PERR("CreateWindowEx() failed\n");
         free(w);
         return NULL;
      }
 
    SetLastError(0);
-   if (!SetWindowLong(w->window, GWL_USERDATA, (LONG)w) && (GetLastError() != 0))
+   if (!SetWindowLongPtr(w->window, GWL_USERDATA, (LONG)w) && (GetLastError() != 0))
      {
+        EINA_ERROR_PERR("SetWindowLongPtr() failed\n");
         DestroyWindow(w->window);
         free(w);
         return NULL;
@@ -912,11 +1213,5 @@ ecore_win32_window_internal_new(Ecore_Win32_Window *parent,
    w->iconified     = 0;
    w->fullscreen    = 0;
 
-   printf (" *** ecore_win32_window_new fin : (%d %d) (%d %d)\n",
-           w->min_width,
-           w->min_height,
-           w->max_width,
-           w->max_height);
-
    return w;
 }
